PALM-meteo: palmmeteo_stdplugins/wrf_utils.py File Reference

PALM-meteo

Classes | Namespaces | Functions | Variables
wrf_utils.py File Reference

## Classes
class | palmmeteo_stdplugins.wrf_utils.WrfPhysics
class | palmmeteo_stdplugins.wrf_utils.WRFCoordTransform
class | palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform
class | palmmeteo_stdplugins.wrf_utils.BilinearRegridder

## Namespaces
namespace | palmmeteo_stdplugins
namespace | palmmeteo_stdplugins.wrf_utils

## Functions
def | palmmeteo_stdplugins.wrf_utils.calc_ph_hybrid (f, it, mu)
def | palmmeteo_stdplugins.wrf_utils.calc_ph_sigma (f, it, mu)
def | palmmeteo_stdplugins.wrf_utils.wrf_t (f, it)
def | palmmeteo_stdplugins.wrf_utils.calc_gp (f, it, ph)
def | palmmeteo_stdplugins.wrf_utils.palm_wrf_gw (f, lon, lat, levels, tidx=0)
def | palmmeteo_stdplugins.wrf_utils.minterp (interp_heights, data_heights, u, v)
def | palmmeteo_stdplugins.wrf_utils.get_wrf_dims (f, lat, lon, xlat, xlong)
def | palmmeteo_stdplugins.wrf_utils.calcgw_wrf (f, lat, lon, levels, tidx=0)
def | palmmeteo_stdplugins.wrf_utils.calcgw_gfs (v, lat, lon)
def | palmmeteo_stdplugins.wrf_utils.combinegw_gfs (grbs, levels, lat, lon)

## Variables
| palmmeteo_stdplugins.wrf_utils.metpy_version_master = int(metpy.__version__.split('.', 1)[0])
int | palmmeteo_stdplugins.wrf_utils.gw_gfs_margin_deg = 5.
| Settings for geostrophic wind. More...
int | palmmeteo_stdplugins.wrf_utils.gw_wrf_margin_km = 10.
int | palmmeteo_stdplugins.wrf_utils.gw_alpha = 1.
| palmmeteo_stdplugins.wrf_utils.ax_ = np.newaxis
| palmmeteo_stdplugins.wrf_utils.parser = argparse.ArgumentParser(description=__doc__)
| palmmeteo_stdplugins.wrf_utils.help
| palmmeteo_stdplugins.wrf_utils.args = parser.parse_args()
| palmmeteo_stdplugins.wrf_utils.f = netCDF4.Dataset(args.wrfout)
| palmmeteo_stdplugins.wrf_utils.t = WRFCoordTransform(f)
| palmmeteo_stdplugins.wrf_utils.mu = f.variables['MUB'][0,:,:] + f.variables['MU'][0,:,:]
| palmmeteo_stdplugins.wrf_utils.gp = f.variables['PH'][0,:,:,:] + f.variables['PHB'][0,:,:,:]
| palmmeteo_stdplugins.wrf_utils.phf
| palmmeteo_stdplugins.wrf_utils.phh
def | palmmeteo_stdplugins.wrf_utils.gp_calc = calc_gp(f, 0, phf)
def | palmmeteo_stdplugins.wrf_utils.delta = gp_calc - gp